Index: src/wp-admin/js/customize-controls.js
===================================================================
--- src/wp-admin/js/customize-controls.js	(revision 26862)
+++ src/wp-admin/js/customize-controls.js	(working copy)
@@ -705,14 +705,13 @@
 			body = $( document.body ),
 			overlay = body.children('.wp-full-overlay');
 
-		// Prevent the form from saving when enter is pressed.
-		$('#customize-controls').on( 'keydown', function( e ) {
-			if ( $( e.target ).is('textarea') )
-				return;
-
-			if ( 13 === e.which ) // Enter
+		// Prevent the form from saving when enter is pressed on an input element.
+		$( '#customize-controls' ).on( 'keydown', function( e ) {
+			var is_enter = ( 13 === e.which );
+			if ( is_enter && $( e.target ).is( 'input:not([type=button])' ) ) {
 				e.preventDefault();
-		});
+			}
+		} );
 
 		// Initialize Previewer
 		previewer = new api.Previewer({
